==> pybeaut-1.1.1b0.tar.gz: pybeaut-1.1.1b0/README.md <==
# <p align="center">☄️ &nbsp;Pybeaut  ☄️</p>
### <p align="center">_A python module to stylize terminal outputs._</p>


## 🔰 Features

- ✅ - Fade effects 
- ✅ - Static & Dynamic colors
- ✅ - Colorate texts
- ✅ - Pigeonhole texts | Texts boxes
- ✅ - Center Texts & Text Alignments
- ✅ - Banners
- **_Other new features will be developing soon . . ._**  

## Don't need this module if:

- 🟥 - Need complex string operations or make terminal pages.
- 🟥 - Make the terminal more beautiful.
- 🟥 - If your system not supports RBG 256bits color representation.

##  ❗️ PLEASE NOTE

> [!IMPORTANT]
> Recently the Pystyle library has suffered an update that contains non-legitimate code and that can put at risk your computer and your data, that's why I have been noticed, as a good action towards the community, to upload my own module renamed as "Pybeaut" to continue giving the service that Pystyle used to give with no malicious contexts.

> [!IMPORTANT]
> This module uses colour representations in RGB format to perform colour operations such as Diagonal or other functions. 
> Some terminals may not support this functionality, especially in non-Windows 10 or 11 environments. 
> Please make sure that your terminal supports RGB colours to avoid display problems.
___

### Recommanations
``If you have any recommendations or new possible implementations of the module features, let us know through an issue in the official repository of the module or by posting a request in the official Pypi portal.``


### 👤 Owner:
- **[@Backist](https://github.com/Backist/)**

### 👤Contributors:
- **[@TheWisker](https://github.com/TheWisker/)**


> This project follows **[Semantic Versioning](https://semver.org/)** 

> Copyright Present Backist and Pybeaut Contributors 2022-2024.

==> pybeaut-1.1.4.tar.gz: pybeaut-1.1.4/README.md <==

# <p align="center">☄️ &nbsp;Pybeaut  ☄️</p>

### <p align="center">_A python module to stylize terminal outputs._</p>

## 🔰 Features

- ✅ - Fade effects
- ✅ - Static & Dynamic colors
- ✅ - Colorate texts
- ✅ - Pigeonhole texts | Texts boxes
- ✅ - Center Texts & Text Alignments
- ✅ - Banners
- **_Other new features will be developing soon . . ._**  

## Don't need this module if

- 🟥 - Need complex string operations or make terminal pages.
- 🟥 - Make the terminal more beautiful.
- 🟥 - If your system not supports RBG 256bits color representation.

## ❗️ PLEASE NOTE

> [!IMPORTANT]
> Recently the Pystyle library has suffered an update that contains non-legitimate code and that can put at risk your computer and your data, that's why I have been noticed, as a good action towards the community, to upload my own module renamed as "Pybeaut" to continue giving the service that Pystyle used to give with no malicious contexts.
> [!IMPORTANT]
> This module uses colour representations in RGB format to perform colour operations such as Diagonal or other functions.
> Some terminals may not support this functionality, especially in non-Windows 10 or 11 environments.
> Please make sure that your terminal supports RGB colours to avoid display problems.
___

### Recommanations

``If you have any recommendations or new possible implementations of the module features, let us know through an issue in the official repository of the module or by posting a request in the official Pypi portal.``

### Owner

- **[@Backist](https://github.com/Backist/)**
  
> This project follows **[Semantic Versioning](https://semver.org/)**
